#
# spec file for package xfdashboard
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 0
Name:           xfdashboard
Version:        1.0.0
Release:        2.2
Summary:        GNOME shell like dashboard for Xfce
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/apps/xfdashboard/start
Source0:        https://archive.xfce.org/src/apps/%{name}/0.8/%{name}-%{version}.tar.bz2
Source8:        xfdashboard.1
Source9:        xfdashboard-settings.1

# WARNING! Please don't add OnlyShowIn key to the desktop file
# to save possibility to be run from under different desktop environments.

# PATCH-FIX-OPENSUSE gh#gmc-holle/xfdashboard#70 xfdashboard-desktop-category.diff dap.darkness@gmail.com -- fixes not-sufficient desktop file category.
Patch0:         xfdashboard-desktop-category.diff

# PATCH-FIX-OPENSUSE xfdashboard-desktopfile-without-binary.diff dap.darkness@gmail.com -- fixes "W: desktopfile-without-binary".
Patch2:         xfdashboard-desktopfile-without-binary.diff

BuildRequires:  appstream-glib
BuildRequires:  clutter-devel
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  libxfce4util-devel >= 4.14.0
BuildRequires:  xfce4-dev-tools
BuildRequires:  pkgconfig(garcon-1)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.14.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.14.0
BuildRequires:  pkgconfig(libxfconf-0)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xinerama)
Requires:       libcanberra-gtk-module-common
Recommends:     %{name}-lang
Recommends:     %{name}-themes

%description
Xfdashboard provides a GNOME shell dashboard like interface for use with Xfce
desktop. It can be configured to run to any keyboard shortcut and when executed
provides an overview of applications currently open enabling the user to switch
between different applications. The search feature works like Xfce's app finder
which makes it convenient to search for and start applications.

%lang_package

%package devel
Summary:        Xfdashboard Development Files
Group:          Development/Libraries/Other
Requires:       libxfdashboard%{so_ver} = %{version}

%description devel
This package provides files required for development for Xfdashboard.

%package themes
Summary:        Themes for Xfdashboard
Group:          System/GUI/XFCE
Requires:       %{name}
BuildArch:      noarch

%description themes
Additional themes for use with Xfdashboard.

%package -n libxfdashboard%{so_ver}
Summary:        Xfdashboard library
Group:          System/GUI/XFCE

%description -n libxfdashboard%{so_ver}
A library providing authenticators for Xfdashboard.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags}"
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_mandir}/man1
gzip -c9 %{SOURCE8} | tee -a %{buildroot}%{_mandir}/man1/%{name}.1.gz
gzip -c9 %{SOURCE9} | tee -a %{buildroot}%{_mandir}/man1/%{name}-settings.1.gz
%fdupes -s %{buildroot}%{_datadir}/themes/%{name}-*
%find_lang %{name} %{?no_lang_C}

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.metainfo.xml

%post -n libxfdashboard%{so_ver} -p /sbin/ldconfig
%postun -n libxfdashboard%{so_ver} -p /sbin/ldconfig

%files
%doc AUTHORS README.md
%license COPYING
%{_bindir}/%{name}*
%{_mandir}/man1/%{name}*.1.gz
%{_datadir}/%{name}
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.xfce.%{name}.metainfo.xml
%{_datadir}/applications/org.xfce.%{name}.desktop
%{_datadir}/applications/org.xfce.%{name}-settings.desktop
%{_sysconfdir}/xdg/autostart/org.xfce.%{name}-autostart.desktop
%{_datadir}/icons/hicolor/*/apps/org.xfce.xfdashboard.*
%{_datadir}/themes/%{name}
%{_libdir}/%{name}

%files lang -f %{name}.lang

%files devel
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/libxfdashboard.pc

%files themes
%{_datadir}/themes/%{name}-*

%files -n libxfdashboard%{so_ver}
%{_libdir}/lib%{name}.so.*

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Mon Aug 15 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.0.0
  * Introduces XfdashboardSettings as settings object for libxfdashboard
  * Introduces XfdashboardPluginSettings as settings object for
    plugins like XfdashboardSettings is for the library
  * Move XfdashboardApplication out of library libxfdashboard into
    application xfdashboard and turn libxfdashboard into a
    complete library
  * Implemented a new color class XfdashboardGradientColor which
    support solid colors (single colors) and path gradients
    Path gradient will follow a path (the outline) and draw
    a gradient orthogonal with color stops along this path
  * Outlines (through XfdashboardoutlineEffect) do now use
    the new XfdashboardGradientColor to support the usual
    solid colors as befeofre as well as a new path gradient
  * Enhanced new color class XfdashboardGradientColor to support
    also linear gradients besided solid colors (single colors)
    and path gradients
    Added support to specify colors for XfdashboardGradientColor in CSS
  * New search provider plugin "recently used" to search through
    list of recently used files provided by GTK+ recent-used manager
  * New plugin "autopin-windows" which will automatically pin each
    window moved to any non-primary monitor and unpins them if moved
    to primary monitor. This plugins runs in daemon mode only
  * Added a new property "visibility", which is stylable, to
    XfdashboardActor, so each actor inherits this new stylable property.
    This stylable property controls if an actor should be visible
    if requested to using clutter_actor_show().
  * Added new actions for key bindings to add, remove, toggle or
    apply CSS classes to a target actor at runtime. Using it by
    default to switch between list and icon mode at application
    view with <Ctrl>-i for icon mode and <Ctrl>-l for list mode
    when application view has the focus. (#16)
  * Fixed crashes with animations when user disabled animations in
    settings (#9)
  * Fixed missing $(XFDASHBOARD_DEBUG_CFLAGS) in all Makefile.am files
    except of libxfdashboard and common folder. So debug macros to print
    debug message where empty and not printed at all, e.g. at plugins
  * Fixed registering focusable actors from other stage interface as
    the main one for primary monitor. (#194)
  * Fixed signal definition of "can-suspend" at XfdashboardCore which
    prevented it to return the correct value if suspend is supported.
    It always returned FALSE even if xfdashboard is run in daemon mode
    and stopped to run background and activating some plugin. (#197)
  * Fixed compiler warning about "'__atomic_load' discards 'volatile'
    qualifier" in g_once_* functions of Glib which was changed in
    releases since 2.66.3
  * Fixed crash on start-up if xfdashboard was started for the very
    first time without any settings in xfconf (#200)
  * Fixed back button not working in sub-menu "all applications" (#21)
  * Fixed incorrect allocation for quicklaunch actor when horizontal
    orientation is used. Thanks to michal4132 for the hint where to
    look at ;) (#2)
  * Fixed switching to workspace of window being activated when window
    was selected at pop-up menu (#15)
  * Fixed intltool lock file bug in make distcheck.
  * Fixed failing to create texture for outlines because either width
    or height is zero (#8)
  * Fixed visual bug in default theme drawing wrong fill and outlines
    corners at workspace selector
  * Fixed not to draw outlines with rounded corners if background type
    has not set rounded corners, as the fill background method
    has already checked for years
  * Fixed AppInfo to match AppStream specification (#4)
  * Fixed lots of typos I've done sadly
  * Fixed enabling full debug builds again with removal of all
    deprecated functions
  * Fixed using deprecated function by using g_memdup2() instead of
    g_memdup() when compiling against GLib 2.67.4 or higher
  * Changed default theme to make use of new path gradients at outlines.
  * Improved window placements in XfdashboardWindowsView
    by centering windows in usused space of last row
  * Do not compile and install the "example-search-provider" plugin
    anymore but include sources and Makefile example
    (now called Makefile.am.example) in distribution file
  * Dropped support of Xfconf legacy (below 4.13.0) because of new
    XfdashboardSettings and XfdashboardPluginSettings object
  * Removed all xfdashboard_*_get_default() function to access
    singleton instances of the subsystems/component, like plugins
    manager etc., as these singleton instances should now to access
    through XfdashboardCore and its xfdashboard_core_get_*(...) functions
  * Background fill color of XfdashboardBackground as well as outline
    color of XfdashboardOutlineEffect do support all types of new color
    class XfdashboardGradientColor, i.e solid colors, linear gradients
    and path gradients
  * Improved algorithm to detect application and determine its desktop
    file (*.desktop) for X11 windows by checking for the X atom called
    "_GTK_APPLICATION_ID" at X11 window properties and at Linux also
    lookup executable file from /proc filesystem in application database.
  * Plugins can now use the debug infrastructure of libxfdashboard
  * Configuration and data files for application added to
    XfdashboardSettings and also added to plugins for plugin-specific
    configuration and data filesystem
  * Implemented function to set "urgent" state at X11 windows
  * Simplied animation creation and usage (or not if disabled) by
    returning an empty animation object which the "done" signal can be
    connected to
  * Disabled applications-search-provider statistics as it uses a file
    instead of settings object or similar and does not work with new
    XfdashboardSettings object.
  * Prepared for newer libxfce4util (version 4.17.2 or higher) which
    changed function xfce_append_quoted to xfce_g_string_append_quoted
  * Translation updates
* Fri Mar  5 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 0.8.1
  * Fixed bug to release an so far unreleased GIcon object at dispose
    function of XfdashboardLabel
  * Moved AppInfo to AppStream metainfo
* Wed Dec 23 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.8.0
  * New application icon which follows rDNS naming
  * Implement pop-up menu which is currently only used by icons in
    quicklaunch when right-clicking at them.
  * The windows in windows view gained support to show also their
    child windows, e.g. open/save dialogs etc.
    (gh#gmc-holle/xfdashboard#132)
  * All windows can now be drag'n'drop from any actor to any other
    window-related actor. (gh#gmc-holle/xfdashboard#79)
  * The window tracker and all other related classes are now
    interfaces to support multiple window systems, like X11, GDK and
    wayland. (gh#gmc-holle/xfdashboard#129)
  * Added a fine-grained controllable debug system.
  * At a theme's layout xml file you can now specify which actor of the
    focusable ones should be selected on theme load.
    (gh#gmc-holle/xfdashboard#144)
  * New actions "selection-move-next", "selection-move-previous",
    "focus-move-first", "focus-move-last" and "focus-move-to" for use at
    custom key bindings were added. They are not bound at the default key
    bindings file installed. (gh#gmc-holle/xfdashboard#144,
    gh#gmc-holle/xfdashboard#145)
  * Window tracker interface now supports a new experimental
    backend for GDK. The backend to use can be controlled with the new
    environment variable XFDASHBOARD_BACKEND. It can be either set to
    "x11" or "gdk". (gh#gmc-holle/xfdashboard#129)
  * Allow user to override CSS files of themes to apply user favourite
    settings. (gh#gmc-holle/xfdashboard#152)
  * Include new translations (gh#gmc-holle/xfdashboard#155)
  * GDK backend is now optional and it will be enabled automatically
    if Clutter backend is available, i.e. FreeBSD does
    not install Clutter with GDK backend. (bxo#13766, bxo#13860)
  * Support also current xfconf versions (4.13.x). (bxo#13824)
  * Support for touch screen which supports "clicking" buttons
    (gh#gmc-holle/xfdashboard#157)
  * Support of application actions defines at desktop entries which
    get listed in the pop-up menus of application buttons.
    (gh#gmc-holle/xfdashboard#158, gh#gmc-holle/xfdashboard#160)
  * Support of "Keywords" of desktop entries which are taken into
    account when searching (gh#gmc-holle/xfdashboard#159)
  * Support for animations. Currently only one actor trigger
    an animation signal to open or close the collapsed area.
  * The user can turn on or off animations in the settings application.
  * Support of more animations. So an actor can request an animation
    when a class or pseudo-class is added or was removed.
  * Support of animation if an actor is destroyed. It will be marked
    as destroyed by adding a CSS pseudo class "destroying".
    The actor will be destroyed finally when animation ends.
  * Introduced a new signal 'actor-created' emitted at stage where a
    newly created actor was placed on. Plugins can connect to this
    signal to detect new actors they are interested in and to modify
    them.
  * Introduced a new signal "initialized" in XfdashboardApplication
    which is emitted when primary instance is fully initialized, that
    means all managers and the stage were set up successfully.
  * New plugin 'middle-click-window-close' which allows the user
    to close windows in windows view with a middle click. This plugin
    is not configurable. (gh#gmc-holle/xfdashboard#128)
  * Added dummy example search provider plugin. It's main purpose is
    to provide a skeleton for creating new search provider plugins.
  * Changed loading key bindings to one-or-nothing to incremental
    loading. (gh#gmc-holle/xfdashboard#167)
  * Added '--version' command-line parameter to determine the version
    of xfdashboard running.
  * Followed main Xfce project by switching to "foreign" mode at automake
  * Added blue theme screenshot. (gh#gmc-holle/xfdashboard#152)
  * The plugin 'hot corner' support also additional monitors and not
    primary monitor only. This option is configurable by user.
  * Use xfce library function instead of implementing own version
  * Enviroment varible XFDASHBOARD_PLUGINS_PATH supports now
    more than one additional path with a colon-seperated list
  * Improved loading performance of images and icons at
    XfdashboardImageContent as it will only start loading when the actor
    using this icon or image is mapped.
  * Improved CSS parser to determine recursion at theme CSS file
    which causes the application to crash due to run out of memory
    (gh#gmc-holle/xfdashboard#143)
  * Rewrote XfdashboardButton by splitting it into a XfdashboardLabel
    class and make XfdashboardButton a sub-class of it.
    XfdashboardLabel is exactly the same what XfdashboardButton was but
    it does not emit the "click" signal.
  * Split XfdashboardLiveWindow into two classes.
    XfdashboardLiveWindowSimple just shows a live preview of a window
    when possible and XfdashboardLiveWindow is a sub-class of it but
    adds a title and controls layer (close button) on top of it.
  * Remove themable property 'show-window-content' from
    XfdashboardLiveWorkspace.
  * The CSS class "primary-monitor" will be added to or removed from
    XfdashboardStageInterface depending on the primary state of
    associated monitor.
  * Made XfdashboardDynamicTableLayout stylable and added a new
    stylable property named "fixed-columns" to disable dynamic
    allocation of columns depending on largest width of a visible
    child found and enforce a fixed number of columns.
    (gh#gmc-holle/xfdashboard#168)
  * Properties 'margin-top', 'margin-bottom', 'margin-left'
    and 'margin-right' of ClutterActor are now themable.
  * Allow windows view to filter windows which are at current workspace
    via a new themable property called 'filter-workspace-windows'.
    (gh#gmc-holle/xfdashboard#126)
  * Replace URLs from goodies.xfce.org to docs.xfce.org (bxo#16229)
  * Lots of larger and smaller bug-fixes
  * Lots of new API documentation
  * Translation updates
* Wed Nov 18 2020 Marcel <marcel@localhost>
- Update to 0.7.90
  * New feature: Support of animation if an actor is destroyed.
    It will be marked as destroyed by adding a CSS pseudo class
    "destroying". The actor will be destroyed finally when
    animation ends.
  * The allocation animation will not be applied when actor is
    created. This behaviour has changed. If an actor should do an
    allocation animation also at the first time shown (created) the
    properties for x/y coordinates and/or width, height must be
    specified at "created" animation
  * New application icon which follows rDNS naming
  * Updated README.md for consistency
  * Use xfce library function instead of implementing own version
  * [plugin] Hot corner: Support also additional monitors and not
    primary monitor only. This option is configurable by user.
  * Enviroment varible XFDASHBOARD_PLUGINS_PATH supports now more
    than one additional path with a colon-seperated list
  * Reduced number of translatable string drastically
  * Translation updates
* Tue Oct 27 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.7.8
  * New feature: Support of more animations. So an actor can request
    an animation when a class or pseudo-class is added or was removed.
    Also an actor requests an animation when it was created and shown
    for the first time. Currently at last an animation is requested
    when the actor was moved and or resized.
  * Followed main Xfce project by switching to "foreign" mode
    at automake
  * Added dummy example search provider plugin. It's main purpose is
    to provide a skeleton for creating new search provider plugins.
  * Fixed a crash when reselecting a search result item on search
    update fails because its container was destroyed while updating.
  * Smaller bug fixes but mostly to silence compiler warnings
  * Translation updates
* Tue Dec  3 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.7.7
  * Fixes missing animations.xml file at all themes in tarball
    (bxo#16230, GH#184)
  * Replace URLs from goodies.xfce.org to docs.xfce.org (bxo#16229)
  * New translations (gl, ru, ru_RU) (bxo#15121, GH#185)
* Fri Nov 29 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.7.6
  * Raised minimum version of Glib to 2.38 for replacements
    of deprecated function g_type_class_add_private()
  * New feature: Support for animations. Currently only one actor
    (XfdashboardCollapseBox) trigger an animation signal to open
    or close the collapsed area. All default themes of xfdashboard
    will slide in or out the collapsed area smoothly when animation
    is enabled (which is enabled by default).
  * New feature: The user can turn on or off animations in the
    settings application.
  * Updated all GOject classes because of deprecation of function
    g_type_class_add_private()
  * Updated copyright years to 2019
  * Fix that valid desktop file for the same desktop ID but found
    at path of lower prioritory will override an invalid desktop
    file for the same desktop ID at path of higher priority. The
    first entry found - valid or invalid - will have the highest
    priority. Later all invalid desktop IDs in the application
    database are removed before populated. (GH#169)
  * Fixed warning "assertion 'GARCON_IS_MENU_DIRECTORY (other)'
    failed" when calling garcon_menu_directory_equal() in function
    _xfdashboard_applications_menu_model_find_similar_menu()
  * Fixed "implicit-fallthrough" compiler warnings in click action
  * Reduced number of release notes in AppData (GH#183)
  * Smaller bug fixes but mostly to silence compiler warnings
  * Updated translations
- Removed deprecated macros
* Sun Aug 12 2018 seife+obs@b1-systems.com
- update to 0.7.5
  - make xfdashboard touchscreen-aware
  - various bugfixes and improvements
  - translation updates
* Tue Oct  3 2017 seife+obs@b1-systems.com
- update to 0.7.4
  - compatibility with old (<= 4.12) and new (>=4.13) xfce libs
  - translation updates
  - adaption to newer libraries
- remove xfdashboard-0.7.3-fix-build-with-gtk3-3_21.diff
* Wed Jul 19 2017 seife+obs@b1-systems.com
- add patch xfdashboard-0.7.3-fix-build-with-gtk3-3_21.diff to fix
  build with GTK3 < 3.22
* Wed Jul 19 2017 seife+obs@b1-systems.com
- update to 0.7.3
  * work ongoing to support non-X11 windowing systems
  * internal code rework
  * adaption for newer GTK / GDK
  * bugfixes
  * translation updates
* Wed Apr 19 2017 seife+obs@b1-systems.com
- update to 0.7.1
  * internal code refactoring
  * compatibility with newer GTK / GDK
  * small bugfixes
  * translation updates
* Wed Sep  7 2016 dap.darkness@gmail.com
- Update to 0.7.0:
  * New feature: Implement pop-up menu which.
  * New plugin 'middle-click-window-close'.
  * Allow windows view to filter windows.
  * Move to workspace where the window to activate is placed on.
  * Introduced a new signal 'actor-created'.
  * Introduced a new signal "initialized" in XfdashboardApplication.
  * Properties of ClutterActor are now themable.
  * Smaller bug-fixes.
  * More API documentation.
  * Updated localizations.
* Sat May 21 2016 dap.darkness@gmail.com
- Update to 0.6.0, changelog at
  https://github.com/gmc-holle/xfdashboard/releases/tag/0.6.0
- Added simple man pages for xfdashboard & xfdashboard-settings.
* Tue Apr  5 2016 dap.darkness@gmail.com
- Update to 0.5.92:
  * Added a "configure" button in "plugins" panel.
  * Fixed crash in search view when Gnome-Shell search provider is
    enabled and DBUS call returned only name for result item.
  * Fixed crash in search view when a result item is focused and
    selected but removed or hidden when search terms are updated.
  * Fixed DBUS method signature to call methods "ActivateResult"
    and "LaunchSearch" in Gnome-Shell search provider.
* Thu Mar 24 2016 dap.darkness@gmail.com
- Update to 0.5.91:
  * Rewrote application object as beginning with Glib 2.47.4 it
    deregisters an application from session's DBUS when returning
    from function g_application_run().
  * Fixed check if a window is really "visible" before trying to
    find the running application in application tracker (GH #114).
  * Fixed usage of an uninitialized application instance (GH #115).
  * Added a compatibility layer to silence compiler warnings.
  * Implemented a new Model class called XfdashboardModel.
  * Fix unpredictable reselections of result items in search view.
  * Some typos are fixed also as well code clean up.
  * Updated translations.
* Mon Feb 29 2016 dap.darkness@gmail.com
- Update to 0.5.90:
  * New feature: Split application into library and application.
  * New feature: A new plugin 'hot corner' was implemented.
  * New feature: Add configuration button in settings application.
  * Fixed a bug at the layout manager's allocation function.
  * Fixed the calculation of number of columns and rows.
  * Fixed visual distortion when allocation of a view.
  * Fixed actors of applications view filling whole space.
  * Implement file monitor to Gnome-Shell search provider plugin.
  * Changed API of object class XfdashboardApplication.
  * Keep order of search providers at search view in order.
  * Add missing public functions to check if a window is maximized.
  * Add CSS class '.window-state-maximized' to actors.
  * Some more bug-fixes, typos fixed etc.
  * Updated translations.
* Wed Feb  3 2016 dap.darkness@gmail.com
- Update to 0.5.5:
  * New feature: A new plugin and the first search provider plugin
    gnome-shell-search-providers was implemented and added;
  * New feature: Implement a new actor in XfdashboardLiveWorkspace;
  * New feature: Add new signal "application-launched";
  * New feature: The applications search provider now counts how
    often an application was launched;
  * New feature: The result set (XfdashboardSearchResultSet) can
    now store a score between 0.0 and 1.0 for each item;
  * New feature: Add pseudo-class ':insensitive';
  * Allow moving a window from one monitor to another;
  * XfdashboardButton supports settings GIcon now;
  * Improved hash value creation for icon names and GIcon;
  * Improved sharing cached image contents;
  * Activating a result item in search view or launching external
    application to perform search in application of search provider
    will now quit (standalone) or suspend (daemon mode) application;
  * Moved logic to handle mapping of actors for result items;
  * Limit number of search results shown for each search provider;
  * Fix starting a real new application instance;
  * Fix visual error at applications view when using icon mode and
    crashes of xfdashboard (GH #109 and GH #110);
  * Lots of bug-fixes, really really really a lot;
  * Fixed lots of typos;
  * Fixed lots of compiler warnings;
  * Updated translations.
- Removed xfdashboard-0.5.4-opensuse-13.1.diff.
* Tue Dec 22 2015 dap.darkness@gmail.com
- Added xfdashboard-0.5.4-opensuse-13.1.diff vs.
  openSUSE 13.1' build issue, see more at
  https://bugzilla.xfce.org/show_bug.cgi?id=12372
* Sun Dec 20 2015 dap.darkness@gmail.com
- Update to 0.5.4:
  * New feature: A theme can define which actors are focusable;
  * New feature: Implemented XfdashboardActionButton button type;
  * Implement action signal "exit" at XfdashboardApplication;
  * Splitted function to determine desktop ID;
  * Improved behaviour to use mouse wheel to change workspace;
  * Added kudos to AppData;
  * Implemented a workaround for broken director monitor in Glib when running FreeBSD;
  * Lots of bug-fixes, really a lot;
  * Updated translations.
* Sun Nov 15 2015 dap.darkness@gmail.com
- Update to 0.5.3:
  * New feature: Implemented a basic and simple plugin manager;
  * Added new environment variable XFDASHBOARD_FORCE_NEW_INSTANCE;
  * Rewrote view and search manager;
  * Smaller improvements, e.g. replacing all GTK+ stock icon names
    with corresponding ones from Icon Naming Specification;
  * Fixed bug that the view will be enforced to be shown (again);
  * Hopefully fixed a bug causing visual glitches in search view;
  * Fixed a possible memory leak when unregistering a view;
  * More bug-fixes;
  * Updated translations;
  * Added new translation: lt.
- Removed xfdashboard-0.5.2-E-64bit-portability-issue.diff.
* Wed Nov  4 2015 dap.darkness@gmail.com
- Added xfdashboard-0.5.2-E-64bit-portability-issue.diff
  vs. 64bit-portability-issue error, see more at
  https://github.com/gmc-holle/xfdashboard/issues/101 or at
  http://lists.opensuse.org/opensuse-factory/2015-11/msg00137.html
- Renamed xfdashboard-0.3.8-desktop-category.diff into
  xfdashboard-desktop-category.diff as not merged by upstream.
* Wed Oct 14 2015 dap.darkness@gmail.com
- Update to 0.5.2:
  * Applied a bug fix. It tracks screen size changes to resize
    stage size at systems where needed. (GH #95)
  * The application tracker now keeps a list of windows for an
    application in a sorted order of last activation of a window.
  * A new configuration option "/always-launch-new-instance" was
    implemented. (GH #97)
  * The application tracker now considers desktop files in
    sub-directories if it was not found. (GH #99)
  * Some smaller improvements.
  * Some bug-fixes.
  * Updated translations.
* Mon Sep 28 2015 dap.darkness@gmail.com
- Update to 0.5.1:
  * Implemented new experimental code to delay window content
    creation finally and made it configurable.
  * Implemented an application tracker which tries to determine and
    to keep track of running applications.
  * With the implementation of the application tracker also running
    application which are not stored as favourites in quicklaunch
    will be added dynamically as temporary application buttons
    which look the same as stored favourites one.
  * Favourite will get CSS class '.favourite-app' added to its
    actor while dynamically added non-favourite actors get the CSS
    class '.dynamic-app' added.
  * Hide all dynamically added non-favourite actors when a
    drag'n'drop action is in progress.
  * Partially rewrote build system to create a static library for
    all files except the main file containing the main() function.
  * Began adding gtk-doc documentation annotations to various files.
  * Remove calls to xfdashboard_actor_contains_child_deep() and
    replaced them with clutter_actor_contains()
  * Add command-line option "--view". This command-line option
    "--view [internal name of view]" allows to specify which view to
    show when xfdashboard gets visible. This will only be applied
    once. It "overrides" any view configured in settings. (#12144)
  * Add session management to xfdashboard to restart it if it
    crashes (#12143)
  * Fixed a bug that pinned windows are not shown at newly created
    (but not current) workspace at XfdashboardLiveWorkspace
  * Fixed settings application to set xfconf property
    '/switch-to-view-on-resume' instead of '/switch-view-on-resume'
  * Fixed a warning printed to console when the setting
    "gtk-tooltip-timeout" was requested as it is deprecated and
    ignored by GTK+ derived application since GTK+ 3.10 and higher.
  * Some other bug-fixes.
* Tue Aug 11 2015 tiwai@suse.de
- include /usr/share/appdata to file list for fixing build on old
  distros
* Sat Jun 13 2015 dap.darkness@gmail.com
- Update to 0.5.0:
  * Added new experimental code to delay window content creation.
    It will make the application "feel" faster on machines with
    slow graphics card (e.g. slow texture creation or uploading).
    A resume queue was implemented which will create the window
    texture one after one when the application is idle. This should
    help not to block the application at start-up or when switching
    to workspaces with many windows resulting in a "feeling" that
    the application is faster and more responsive. To enable this
    experimental code the enviroment variable
    XFDASHBOARD_WINDOW_CONTENT_RESUME_ON_IDLE must be set to
    non-zero value when the application is started regardless
    if stand-alone or daemon mode.
  * New feature is a emblem effect called XfdashboardEmblemEffect.
    This new effect allows an icon to be drawn over an actor and
    can be added multiple times.
  * Improved tooltip to behave more the tooltip known of GTK+.
  * Improved search responsiveness by delaying initial search. But
    this delay is turned off by default so it behave like before.
    The delay can be configured in the settings. (GH #86)
  * XfdashboardLiveWindow will now reflect window state changes
    like urgent, minimized and pinned as CSS classes to get styles
    applied at one or more of this states.
  * The icon to show for an missing image can now be themed via the
    property 'missing-icon-name' at XfdashboardImageContent.
    It is not hard-coded to 'gtk-missing-image' anymore.
  * Implemented a new themable property 'show-window-content' at
    XfdashboardLiveWorkspace to manage if a workspace actor (e.g.
    used in workspace selector) should show the window content of
    the windows at this workspace or to show the windows' icon
    instead. (GH #89)
  * Implemented also a new themable property 'background-image-type'
    at XfdashboardLiveWorkspace which behaves like the property
    'background-image-type' at XfdashboardStage(Interface). (GH #81)
  * Implemented a new property 'show-current-monitor-only' at
    XfdashboardWorkspaceSelector to limit the windows to show at
    XfdashboardLiveWorkspace to the windows of the monitor where
    the selector is placed on. This feature can only be enabled in
    layout but not in CSS. All themes enable this feature. (GH #87)
  * Implemented a new signal 'window-monitor-changed' at window
    tracker to signal that a window has moved from one monitor to
    another. This signal is used by the windows view to determine
    if the moved window has to stay in this view or if another
    window view instance has to create an actor for this window and
    to handle it. (GH #88)
  * Do not track and handle window movements and resizes if the
    application is suspended. This should lower CPU usage while
    application is suspended and a window is moved or resized.
    (GH #44)
  * Reimplement old "hack" resize stage to screen size but this
    time also listen for screen size changes. This implementation
    is only needed when using Clutter version 1.17.1 or lower.
    It is checked at run-time if this "hack" is needed. (GH #95)
  * Changed method to find desktop window. This fixes problems
    finding desktop window in daemon mode (GH #80)
  * Show settings application menu entry also in other desktop
    environments than Xfce. (GH #78)
  * Fixed a bug that the windows view did not recognize that a
    window has move to the current active workspace when a
    workspace was removed and it did not show the moved window in
    view. (GH #91)
  * Fixed a bug that the functions to determine the preferred width
    and height in XfdashboardScaledTableLayout are called
    recursively and crashes the application
  * Fixed calculation of workspace selector's size by fraction or
    maximum size in multi-monitor setup by using size of
    XfdashboardStageInterface for calculation instead of stage's
    size which is the size of all monitors.
  * Fixed duplicate IDs in CSS selectors by throwing an error.
  * Lots of memleaks fixed.
  * Lots of other bug-fixes.
  * Lots of typos fixed.
  * Updated translations:
    + es (prflr88);
    + he (GenghisKhan);
    + it_IT (cri);
    + sr (salepetronije);
  * New translations:
    + fr (jc1).
* Sun May 31 2015 dap.darkness@gmail.com
- Update to 0.4.2:
  * Fixed check against wrong major version of Clutter for old hack
    to resize stage to screen size. Also changed this check from
    compile-time to runtime.
  * Changed method to find desktop window. This fixes problems
    finding desktop window in daemon mode.
- Fixed xfdashboard-desktopfile-without-binary.diff again.
* Mon Apr 13 2015 dap.darkness@gmail.com
- Update to 0.4.0:
  * Updated translations.
  * Minor fixes.
- Fixed xfdashboard-desktopfile-without-binary.diff
* Sun Mar 29 2015 dap.darkness@gmail.com
- Update to 0.3.91:
  * Fixed a bug that translations are not used in xfdashboard.
  * Fixed a visual bug in XfdashboardStageInterface which caused
    that clipping in XfdashboardViewpad did not work anymore and
    overlapped other actors.
  * Implemented a box layout manager called XfdashboardBoxLayout
    which is derived from ClutterBoxLayout and inherits all
    functions and properties. It only disregards text direction
    settings to enforce a horizontal left-to-right layout of its
    children always. (GH #66)
  * Fixed warning about using deprecated functions when compiling
    against GTK+ 3.14 or higher.
* Thu Mar 19 2015 dap.darkness@gmail.com
- Update to 0.3.90:
  * New feature: Implemented multi-monitor support. This also added
    a new interface ID "secondary" to themes which specifies how
    the stage for non-primary monitors looks like. (#14)
  * Added an option "/components/applications-view/show-all-apps"
    to settings which adds an "All applications" menu entry to
    applications view and shows all installed applications in this
    menu. It is disabled by default but configurable in settings.
  * Replaced GTK+ stock icons with named icons
  * Enforce X11 backend at Clutter to prevent start-up crashes when
    using Clutter 1.21.4 or higher which uses GDK backend by default.
    xfdashboard uses some X11 related function at Clutter (#73)
  * Clear startup-notification when application enters main loop
  * Fixed compiler warnings, build system and other smaller bug fixes
  * Updated translations:
    + es (prflr88)
    + he (GenghisKhan)
    + it_IT (cri)
    + sr (salepetronije)
* Sat Feb 21 2015 dap.darkness@gmail.com
- Update to 0.3.9:
  * Notice: Raised minimum version of Glib to 2.32;
  * New feature: XfdashboardDesktopAppInfo;
  * New feature: XfdashboardApplicationDatabase;
  * Removed feature: Removed hotkey tracker;
  * Implement "activating" signal at XfdashboardTooltipAction;
  * Rewrote XfdashboardSearchView;
  * Added "GenericName" to application desktop file;
  * Fixed compiler warnings, build system;
  * Added translations:
    + es;
    + he;
    + it_IT;
    + sr.
- Packaging:
  * Removed xfdashboard-0.3.8-void-return.diff
    as already provided via new release;
  * Updated xfdashboard-desktopfile-without-binary.diff;
  * Added lang subpackage.
* Sat Jan 31 2015 dap.darkness@gmail.com
- Fixed patches descriptions again.
- Autostart subpackage was merged into the main one.
* Fri Jan 30 2015 dap.darkness@gmail.com
- Fixed xfdashboard-0.3.8-desktop-category.diff
  to pass pull request review.
- Added xfdashboard-desktopfile-without-binary.diff
  vs. "W: desktopfile-without-binary".
- Fixed patches descriptions.
* Thu Jan 29 2015 dap.darkness@gmail.com
- SUSEficated.
- Added xfdashboard-0.3.8-desktop-category.diff
  to fit openSUSE desktop files rules.
- Added xfdashboard-0.3.8-voidreturn.diff
  to fix serious compiler warnings.
  https://github.com/gmc-holle/xfdashboard/issues/68
* Sat Jan 24 2015 nonamedotc@fedoraproject.org
- Update to 0.3.8
* Sat Jan 17 2015 nonamedotc@fedoraproject.org
- Update to 0.3.6
- Added libxfce4util-devel as BR for building settings manager
* Mon Jan 12 2015 nonamedotc@fedoraproject.org
- Update to 0.3.5
* Thu Nov 27 2014 nonamedotc@fedoraproject.org
- Update to 0.3.4
- Move additional themes provided to -themes subpackage
* Mon Oct 20 2014 kevin@scrye.com
- Update to 0.3.3
* Mon Sep  8 2014 nonamedotc@fedoraproject.org
- Updated to latest upstream version
- New features included
* Wed Sep  3 2014 nonamedotc@fedoraproject.org
- Updated to latest upstream version
* Mon Aug 18 2014 rel-eng@lists.fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild
* Tue Jul 22 2014 nonamedotc@fedoraproject.org
- Latest upstream version with bugfixes and enhancements
- Removed ChangeLog from doc
* Sun Jul 20 2014 nonamedotc@fedoraproject.org
- Updated to latest upstream version
* Sat Jul 12 2014 nonamedotc@fedoraproject.org
- Initial build for F22
* Wed Jun 11 2014 nonamedotc@fedoraproject.org
- Updated to latest upstream release
- Added appdata file
* Wed Jun  4 2014 nonamedotc@fedoraproject.org
- Updated to latest version
- Added application icons
* Tue May 20 2014 nonamedotc@fedoraproject.org
- Fixed URL
- Updated to 0.1.91 - API change with this update
- Removed TODO
- Added BuildRequires for desktop-file-utils
- desktop file added - will show in XFCE menu
- desktop file for autostart added
* Fri May  2 2014 nonamedotc@fedoraproject.org
- Update to 0.1.90
- multiple bug fixes and improvements
* Sun Mar 23 2014 nonamedotc@fedoraproject.org
- Updated to 0.1.6
* Sat Mar  8 2014 nonamedotc@fedoraproject.org
- Updated to latest release containing new enhancements
* Tue Feb 25 2014 nonamedotc@fedoraproject.org
- Patch for enabling workspace switching added
- Upstream bug - issue#1 on github
* Mon Feb 24 2014 nonamedotc@fedoraproject.org
- Updated to the latest upstream version
- Includes theming support (provides a default theme)
* Tue Feb 11 2014 nonamedotc@fedoraproject.org
- Updated to the latest upstream version
* Mon Feb 10 2014 nonamedotc@fedoraproject.org
- Corrected flags used for building the package
- Edited the description
* Sun Feb  2 2014 nonamedotc@fedoraproject.org
- Corrected version used for packaging
- Added the doc files
* Wed Jan 29 2014 nonamedotc@fedoraproject.org
- Initial build for Fedora
